@@ -1,5 +1,5 @@
 //! Pre HTML codegen phase
-use crate::backend::data::{Atom, Text, Enclosure, EnclosureKind};
+use crate::compiler::data::{Atom, Text, Enclosure, EnclosureKind};
 use crate::backend::{Ast, Tag};
 
 
